@@ -437,7 +437,7 @@ def set_charset():
 
         elif choice == '4':
             file = input('\n\nEnter File containing characterset :')
-            os.chdir(..)
+            os.chdir("..")
             fil = ''
             try:
                 with open(file,'r') as f:
